==> 1.5.1.zip: fscan/WebScan/info/rules.go <==
package info

type RuleData struct {
	Name string
	Type string
	Rule string
}

type Md5Data struct {
	Name   string
	Md5Str string
}

var RuleDatas = []RuleData{
	{"Shiro", "headers", "(=deleteMe|rememberMe=)"},
	{"Portainer(Docker管理)", "code", "(portainer.updatePassword|portainer.init.admin)"},
	{"Gogs简易Git服务", "cookie", "(i_like_gogs)"},
	{"Gitea简易Git服务", "cookie", "(i_like_gitea)"},
	{"宝塔-BT.cn", "code", "(app.bt.cn/static/app.png|安全入口校验失败)"},
	{"Nexus", "code", "(Nexus Repository Manager)"},
	{"Nexus", "cookie", "(NX-ANTI-CSRF-TOKEN)"},
	{"Harbor", "code", "(<title>Harbor</title>)"},
	{"Harbor", "cookie", "(harbor-lang)"},
	{"禅道", "code", "(/theme/default/images/main/zt-logo.png)"},
	{"禅道", "cookie", "(zentaosid)"},
	{"协众OA", "code", "(Powered by 协众OA)"},
	{"协众OA", "cookie", "(CNOAOASESSID)"},
	{"xxl-job", "code", "(分布式任务调度平台XXL-JOB)"},
	{"atmail-WebMail", "cookie", "(atmail6)"},
	{"atmail-WebMail", "code", "(Powered by Atmail)"},
	{"atmail-WebMail", "code", "(/index.php/mail/auth/processlogin)"},
	{"weblogic", "code", "(/console/framework/skins/wlsconsole/images/login_WebLogic_branding.png|Welcome to Weblogic Application Server|<i>Hypertext Transfer Protocol -- HTTP/1.1</i>)"},
	{"致远OA", "code", "(/seeyon/USER-DATA/IMAGES/LOGIN/login.gif)"},
	{"Typecho", "code", "(Typecho</a>)"},
	{"金蝶EAS", "code", "(easSessionId)"},
	{"phpMyAdmin", "cookie", "(pma_lang|phpMyAdmin)"},
	{"phpMyAdmin", "code", "(/themes/pmahomme/img/logo_right.png)"},
	{"H3C-AM8000", "code", "(AM8000)"},
	{"360企业版", "code", "(360EntWebAdminMD5Secret)"},
	{"H3C公司产品", "code", "(service@h3c.com)"},
	{"H3C ICG 1000", "code", "(ICG 1000系统管理)"},
	{"Citrix-Metaframe", "code", "(window.location=\"/Citrix/MetaFrame)"},
	{"H3C ER5100", "code", "(ER5100系统管理)"},
	{"阿里云CDN", "code", "(cdn.aliyuncs.com)"},
	{"CISCO_EPC3925", "code", "(Docsis_system)"},
	{"CISCO ASR", "code", "(CISCO ASR)"},
	{"H3C ER3200", "code", "(ER3200系统管理)"},
	{"万户ezOFFICE", "headers", "(LocLan)"},
	{"万户网络", "code", "(css/css_whir.css)"},
	{"Spark_Master", "code", "(Spark Master at)"},
	{"华为_HUAWEI_SRG2220", "code", "(HUAWEI SRG2220)"},
	{"蓝凌EIS智慧协同平台", "code", "(/scripts/jquery.landray.common.js)"},
	{"深信服ssl-vpn", "code", "(login_psw.csp)"},
	{"华为 NetOpen", "code", "(/netopen/theme/css/inFrame.css)"},
	{"Citrix-Web-PN-Server", "code", "(Citrix Web PN Server)"},
	{"juniper_vpn", "code", "(welcome.cgi?p=logo|/images/logo_juniper_reversed.gif)"},
	{"360主机卫士", "headers", "(zhuji.360.cn)"},
	{"Nagios", "headers", "(Nagios Access)"},
	{"H3C ER8300", "code", "(ER8300系统管理)"},
	{"Citrix-Access-Gateway", "code", "(Citrix Access Gateway)"},
	{"华为 MCU", "code", "(McuR5-min.js)"},
	{"TP-LINK Wireless WDR3600", "code", "(TP-LINK Wireless WDR3600)"},
	{"泛微协同办公OA", "headers", "(ecology_JSessionid)"},
	{"华为_HUAWEI_ASG2050", "code", "(HUAWEI ASG2050)"},
	{"360网站卫士", "code", "(360wzb)"},
	{"Citrix-XenServer", "code", "(Citrix Systems, Inc. XenServer)"},
	{"H3C ER2100V2", "code", "(ER2100V2系统管理)"},
	{"zabbix", "cookie", "(zbx_sessionid)"},
	{"zabbix", "code", "(images/general/zabbix.ico|Zabbix SIA)"},
	{"CISCO_VPN", "headers", "(webvpn)"},
	{"360站长平台", "code", "(360-site-verification)"},
	{"H3C ER3108GW", "code", "(ER3108GW系统管理)"},
	{"o2security_vpn", "headers", "(client_param=install_active)"},
	{"H3C ER3260G2", "code", "(ER3260G2系统管理)"},
	{"H3C ICG1000", "code", "(ICG1000系统管理)"},
	{"CISCO-CX20", "code", "(CISCO-CX20)"},
	{"H3C ER5200", "code", "(ER5200系统管理)"},
	{"linksys-vpn-bragap14-parintins", "code",
		"(linksys-vpn-bragap14-parintins)"},
	{"360网站卫士常用前端公共库", "code", "(libs.useso.com)"},
	{"H3C ER3100", "code", "(ER3100系统管理)"},
	{"H3C-SecBlade-FireWall", "code", "(js/MulPlatAPI.js)"},
	{"360webfacil_360WebManager", "code", "(publico/template/)"},
	{"Citrix_Netscaler", "code", "(ns_af)"},
	{"H3C ER6300G2", "code", "(ER6300G2系统管理)"},
	{"H3C ER3260", "code", "(ER3260系统管理)"},
	{"华为_HUAWEI_SRG3250", "code", "(HUAWEI SRG3250)"},
	{"exchange", "code", "(/owa/auth.owa)"},
	{"Spark_Worker", "code", "(Spark Worker at)"},
	{"H3C ER3108G", "code", "(ER3108G系统管理)"},
	{"深信服防火墙类产品", "code", "(SANGFOR FW)"},
	{"Citrix-ConfProxy", "code", "(confproxy)"},
	{"360网站安全检测", "code", "(webscan.360.cn/status/pai/hash)"},
	{"H3C ER5200G2", "code", "(ER5200G2系统管理)"},
	{"华为（HUAWEI）安全设备", "code", "(sweb-lib/resource/)"},
	{"H3C ER6300", "code", "(ER6300系统管理)"},
	{"华为_HUAWEI_ASG2100", "code", "(HUAWEI ASG2100)"},
	{"TP-Link 3600 DD-WRT", "code", "(TP-Link 3600 DD-WRT)"},
	{"NETGEAR WNDR3600", "code", "(NETGEAR WNDR3600)"},
	{"H3C ER2100", "code", "(ER2100系统管理)"},
	{"绿盟下一代防火墙", "code", "(NSFOCUS NF)"},
	{"jira", "code", "(jira.webresources)"},
	{"金和协同管理平台", "code", "(金和协同管理平台)"},
	{"Citrix-NetScaler", "code", "(NS-CACHE)"},
	{"linksys-vpn", "headers", "(linksys-vpn)"},
	{"通达OA", "code", "(/static/images/tongda.ico)"},
	{"华为（HUAWEI）Secoway设备", "code", "(Secoway)"},
	{"华为_HUAWEI_SRG1220", "code", "(HUAWEI SRG1220)"},
	{"H3C ER2100n", "code", "(ER2100n系统管理)"},
	{"H3C ER8300G2", "code", "(ER8300G2系统管理)"},
	{"金蝶政务GSiS", "code", "(/kdgs/script/kdgs.js)"},
	{"Jboss", "code", "(Welcome to JBoss|jboss.css)"},
	{"Jboss", "headers", "(JBoss)"},
	{"泛微E-mobile", "code", "(Weaver E-mobile)"},
	{"齐治堡垒机", "code", "(logo-icon-ico72.png)"},
}

var Md5Datas = []Md5Data{
	{"BIG-IP", "04d9541338e525258daf47cc844d59f3"},
	{"蓝凌OA", "302464c3f6207d57240649926cfc7bd4"},
	{"JBOSS", "799f70b71314a7508326d1d2f68f7519"},
	{"锐捷网关", "d8d7c9138e93d43579ebf2e384745ba8"},
	{"深信服edr", "0b24d4d5c7d300d50ee1cd96059a9e85"},
	{"致远OA", "cdc85452665e7708caed3009ecb7d4e2"},
	{"致远OA", "17ac348fcce0b320e7bfab3fe2858dfa"},
	{"致远OA", "57f307ad3764553df84e7b14b7a85432"},
	{"致远OA", "3c8df395ec2cbd72782286d18a286a9a"},
	{"致远OA", "2f761c27b6b7f9386bbd61403635dc42"},
	{"齐治堡垒机", "48ee373f098d8e96e53b7dd778f09ff4"},
	{"SprintBoot", "0488faca4c19046b94d07c3ee83cf9d6"},
	{"ThinkPHP", "f49c4a4bde1eec6c0b80c2277c76e3db"},
	{"通达OA", "ed0044587917c76d08573577c8b72883"},
	{"泛微OA", "41eca7a9245394106a09b2534d8030df"},
	{"泛微OA", "c27547e27e1d2c7514545cd8d5988946"},
	{"泛微OA", "9b1d3f08ede38dbe699d6b2e72a8febb"},
	{"泛微OA", "281348dd57383c1f214ffb8aed3a1210"},
}

==> 1.6.1.zip: fscan/WebScan/info/rules.go <==
package info

type RuleData struct {
	Name string
	Type string
	Rule string
}

type Md5Data struct {
	Name   string
	Md5Str string
}

var RuleDatas = []RuleData{
	{"Shiro", "headers", "(=deleteMe|rememberMe=)"},
	{"Portainer(Docker管理)", "code", "(portainer.updatePassword|portainer.init.admin)"},
	{"Gogs简易Git服务", "cookie", "(i_like_gogs)"},
	{"Gitea简易Git服务", "cookie", "(i_like_gitea)"},
	{"宝塔-BT.cn", "code", "(app.bt.cn/static/app.png|安全入口校验失败)"},
	{"Nexus", "code", "(Nexus Repository Manager)"},
	{"Nexus", "cookie", "(NX-ANTI-CSRF-TOKEN)"},
	{"Harbor", "code", "(<title>Harbor</title>)"},
	{"Harbor", "cookie", "(harbor-lang)"},
	{"禅道", "code", "(/theme/default/images/main/zt-logo.png)"},
	{"禅道", "cookie", "(zentaosid)"},
	{"协众OA", "code", "(Powered by 协众OA)"},
	{"协众OA", "cookie", "(CNOAOASESSID)"},
	{"xxl-job", "code", "(分布式任务调度平台XXL-JOB)"},
	{"atmail-WebMail", "cookie", "(atmail6)"},
	{"atmail-WebMail", "code", "(Powered by Atmail)"},
	{"atmail-WebMail", "code", "(/index.php/mail/auth/processlogin)"},
	{"weblogic", "code", "(/console/framework/skins/wlsconsole/images/login_WebLogic_branding.png|Welcome to Weblogic Application Server|<i>Hypertext Transfer Protocol -- HTTP/1.1</i>)"},
	{"致远OA", "code", "(/seeyon/USER-DATA/IMAGES/LOGIN/login.gif)"},
	{"致远OA", "code", "(/seeyon/common/)"},
	{"discuz", "code", "(content=\"Discuz! X\")"},
	{"Typecho", "code", "(Typecho</a>)"},
	{"金蝶EAS", "code", "(easSessionId)"},
	{"phpMyAdmin", "cookie", "(pma_lang|phpMyAdmin)"},
	{"phpMyAdmin", "code", "(/themes/pmahomme/img/logo_right.png)"},
	{"H3C-AM8000", "code", "(AM8000)"},
	{"360企业版", "code", "(360EntWebAdminMD5Secret)"},
	{"H3C公司产品", "code", "(service@h3c.com)"},
	{"H3C ICG 1000", "code", "(ICG 1000系统管理)"},
	{"Citrix-Metaframe", "code", "(window.location=\"/Citrix/MetaFrame)"},
	{"H3C ER5100", "code", "(ER5100系统管理)"},
	{"阿里云CDN", "code", "(cdn.aliyuncs.com)"},
	{"CISCO_EPC3925", "code", "(Docsis_system)"},
	{"CISCO ASR", "code", "(CISCO ASR)"},
	{"H3C ER3200", "code", "(ER3200系统管理)"},
	{"万户ezOFFICE", "headers", "(LocLan)"},
	{"万户网络", "code", "(css/css_whir.css)"},
	{"Spark_Master", "code", "(Spark Master at)"},
	{"华为_HUAWEI_SRG2220", "code", "(HUAWEI SRG2220)"},
	{"蓝凌EIS智慧协同平台", "code", "(/scripts/jquery.landray.common.js)"},
	{"深信服ssl-vpn", "code", "(login_psw.csp)"},
	{"华为 NetOpen", "code", "(/netopen/theme/css/inFrame.css)"},
	{"Citrix-Web-PN-Server", "code", "(Citrix Web PN Server)"},
	{"juniper_vpn", "code", "(welcome.cgi?p=logo|/images/logo_juniper_reversed.gif)"},
	{"360主机卫士", "headers", "(zhuji.360.cn)"},
	{"Nagios", "headers", "(Nagios Access)"},
	{"H3C ER8300", "code", "(ER8300系统管理)"},
	{"Citrix-Access-Gateway", "code", "(Citrix Access Gateway)"},
	{"华为 MCU", "code", "(McuR5-min.js)"},
	{"TP-LINK Wireless WDR3600", "code", "(TP-LINK Wireless WDR3600)"},
	{"泛微OA", "headers", "(ecology_JSessionid)"},
	{"泛微OA", "code", "(/spa/portal/public/index.js)"},
	{"华为_HUAWEI_ASG2050", "code", "(HUAWEI ASG2050)"},
	{"360网站卫士", "code", "(360wzb)"},
	{"Citrix-XenServer", "code", "(Citrix Systems, Inc. XenServer)"},
	{"H3C ER2100V2", "code", "(ER2100V2系统管理)"},
	{"zabbix", "cookie", "(zbx_sessionid)"},
	{"zabbix", "code", "(images/general/zabbix.ico|Zabbix SIA)"},
	{"CISCO_VPN", "headers", "(webvpn)"},
	{"360站长平台", "code", "(360-site-verification)"},
	{"H3C ER3108GW", "code", "(ER3108GW系统管理)"},
	{"o2security_vpn", "headers", "(client_param=install_active)"},
	{"H3C ER3260G2", "code", "(ER3260G2系统管理)"},
	{"H3C ICG1000", "code", "(ICG1000系统管理)"},
	{"CISCO-CX20", "code", "(CISCO-CX20)"},
	{"H3C ER5200", "code", "(ER5200系统管理)"},
	{"linksys-vpn-bragap14-parintins", "code", "(linksys-vpn-bragap14-parintins)"},
	{"360网站卫士常用前端公共库", "code", "(libs.useso.com)"},
	{"H3C ER3100", "code", "(ER3100系统管理)"},
	{"H3C-SecBlade-FireWall", "code", "(js/MulPlatAPI.js)"},
	{"360webfacil_360WebManager", "code", "(publico/template/)"},
	{"Citrix_Netscaler", "code", "(ns_af)"},
	{"H3C ER6300G2", "code", "(ER6300G2系统管理)"},
	{"H3C ER3260", "code", "(ER3260系统管理)"},
	{"华为_HUAWEI_SRG3250", "code", "(HUAWEI SRG3250)"},
	{"exchange", "code", "(/owa/auth.owa)"},
	{"Spark_Worker", "code", "(Spark Worker at)"},
	{"H3C ER3108G", "code", "(ER3108G系统管理)"},
	{"深信服防火墙类产品", "code", "(SANGFOR FW)"},
	{"Citrix-ConfProxy", "code", "(confproxy)"},
	{"360网站安全检测", "code", "(webscan.360.cn/status/pai/hash)"},
	{"H3C ER5200G2", "code", "(ER5200G2系统管理)"},
	{"华为（HUAWEI）安全设备", "code", "(sweb-lib/resource/)"},
	{"华为（HUAWEI）USG", "code", "(UI_component/commonDefine/UI_regex_define.js)"},
	{"H3C ER6300", "code", "(ER6300系统管理)"},
	{"华为_HUAWEI_ASG2100", "code", "(HUAWEI ASG2100)"},
	{"TP-Link 3600 DD-WRT", "code", "(TP-Link 3600 DD-WRT)"},
	{"NETGEAR WNDR3600", "code", "(NETGEAR WNDR3600)"},
	{"H3C ER2100", "code", "(ER2100系统管理)"},
	{"绿盟下一代防火墙", "code", "(NSFOCUS NF)"},
	{"jira", "code", "(jira.webresources)"},
	{"金和协同管理平台", "code", "(金和协同管理平台)"},
	{"Citrix-NetScaler", "code", "(NS-CACHE)"},
	{"linksys-vpn", "headers", "(linksys-vpn)"},
	{"通达OA", "code", "(/static/images/tongda.ico)"},
	{"华为（HUAWEI）Secoway设备", "code", "(Secoway)"},
	{"华为_HUAWEI_SRG1220", "code", "(HUAWEI SRG1220)"},
	{"H3C ER2100n", "code", "(ER2100n系统管理)"},
	{"H3C ER8300G2", "code", "(ER8300G2系统管理)"},
	{"金蝶政务GSiS", "code", "(/kdgs/script/kdgs.js)"},
	{"Jboss", "code", "(Welcome to JBoss|jboss.css)"},
	{"Jboss", "headers", "(JBoss)"},
	{"泛微E-mobile", "code", "(Weaver E-mobile|weaver,e-mobile)"},
	{"齐治堡垒机", "code", "(logo-icon-ico72.png)"},
	{"ThinkPHP", "headers", "(ThinkPHP)"},
	{"ThinkPHP", "code", "(/Public/static/js/)"},
	{"weaver-ebridge", "code", "(e-Bridge,http://wx.weaver)"},
	{"Laravel", "headers", "(laravel_session)"},
	{"DWR", "code", "(dwr/engine.js)"},
	{"swagger_ui", "code", "(swagger-ui/css|\"swagger\":|swagger-ui.min.js)"},
	{"大汉版通发布系统", "code", "(大汉版通发布系统|大汉网络)"},
	{"druid", "code", "(druid.index|DruidDrivers|DruidVersion|Druid Stat Index)"},
	{"Jenkins", "code", "(Jenkins)"},
	{"红帆OA", "code", "(iOffice)"},
	{"VMware vSphere", "code", "(VMware vSphere)"},
	{"打印机", "code", "(打印机|media/canon.gif)"},
}

var Md5Datas = []Md5Data{
	{"BIG-IP", "04d9541338e525258daf47cc844d59f3"},
	{"蓝凌OA", "302464c3f6207d57240649926cfc7bd4"},
	{"JBOSS", "799f70b71314a7508326d1d2f68f7519"},
	{"锐捷网关", "d8d7c9138e93d43579ebf2e384745ba8"},
	{"深信服edr", "0b24d4d5c7d300d50ee1cd96059a9e85"},
	{"致远OA", "cdc85452665e7708caed3009ecb7d4e2"},
	{"致远OA", "17ac348fcce0b320e7bfab3fe2858dfa"},
	{"致远OA", "57f307ad3764553df84e7b14b7a85432"},
	{"致远OA", "3c8df395ec2cbd72782286d18a286a9a"},
	{"致远OA", "2f761c27b6b7f9386bbd61403635dc42"},
	{"齐治堡垒机", "48ee373f098d8e96e53b7dd778f09ff4"},
	{"SprintBoot", "0488faca4c19046b94d07c3ee83cf9d6"},
	{"ThinkPHP", "f49c4a4bde1eec6c0b80c2277c76e3db"},
	{"通达OA", "ed0044587917c76d08573577c8b72883"},
	{"泛微OA", "41eca7a9245394106a09b2534d8030df"},
	{"泛微OA", "c27547e27e1d2c7514545cd8d5988946"},
	{"泛微OA", "9b1d3f08ede38dbe699d6b2e72a8febb"},
	{"泛微OA", "281348dd57383c1f214ffb8aed3a1210"},
}
